/**
 * @file Angular component Rx service declaration & definition.
 * @copyright © 2017 Tristan Bonsor
 * @license MIT
 */
import { InjectionToken, Provider } from '@angular/core';
import { Action, ActionReducer, ActionReducerMap } from '@ngrx/store/src/models';
import { State } from '@ngrx/store/src/state';
import { Store } from '@ngrx/store/src/store';
import { StoreConfig } from '@ngrx/store/src/store_module';
import { Operator } from 'rxjs';
export { Action };
/**
 * Angular component Rx service.
 */
export declare class ComponentRxService<T> {
    protected state: State<T>;
    protected store: Store<T>;
    /**
     * Get provider for component Rx service.
     *
     * @param {ActionReducerMap<any, any> | InjectionToken<ActionReducerMap<any, any>>} reducers
     * @param {StoreConfig<any, any>} config
     */
    static forComponent(reducers: ActionReducerMap<any, any> | InjectionToken<ActionReducerMap<any, any>>, config?: StoreConfig<any, any>): Provider;
    /**
     * Instantiate component Rx service.
     *
     * @param {ActionReducerMap<any, any> | InjectionToken<ActionReducerMap<any, any>>} reducers Map of reducers.
     * @param {StoreConfig<any, any>} config Store configuration.
     */
    constructor(state: State<T>, store: Store<T>);
    /**
     * Get state observable.
     *
     * @return {State<T>} State observable.
     */
    getStateObservable(): State<T>;
    select<K>(mapFn: (state: T) => K): Store<K>;
    select<a extends keyof T>(key: a): Store<T[a]>;
    lift<R>(operator: Operator<T, R>): Store<R>;
    dispatch<V extends Action = Action>(action: V): void;
    next(action: Action): void;
    error(err: any): void;
    complete(): void;
    addReducer<State, Actions extends Action = Action>(key: string, reducer: ActionReducer<State, Actions>): void;
    removeReducer<Key extends keyof T>(key: Key): void;
}
