/**
 * @file Angular component Rx service declaration & definition.
 * @copyright © 2017 Tristan Bonsor
 * @license MIT
 */
import { Injectable, InjectionToken } from '@angular/core';
import { ACTIONS_SUBJECT_PROVIDERS } from '@ngrx/store/src/actions_subject';
import { REDUCER_MANAGER_PROVIDERS } from '@ngrx/store/src/reducer_manager';
import { SCANNED_ACTIONS_SUBJECT_PROVIDERS } from '@ngrx/store/src/scanned_actions_subject';
import { State, STATE_PROVIDERS } from '@ngrx/store/src/state';
import { Store, STORE_PROVIDERS } from '@ngrx/store/src/store';
import { _initialStateFactory, } from '@ngrx/store/src/store_module';
import { _INITIAL_STATE, _REDUCER_FACTORY, INITIAL_REDUCERS, INITIAL_STATE, META_REDUCERS, REDUCER_FACTORY, } from '@ngrx/store/src/tokens';
import { combineReducers, createReducerFactory } from '@ngrx/store/src/utils';
/**
 * Angular component Rx service.
 */
var ComponentRxService = (function () {
    /**
     * Instantiate component Rx service.
     *
     * @param {ActionReducerMap<any, any> | InjectionToken<ActionReducerMap<any, any>>} reducers Map of reducers.
     * @param {StoreConfig<any, any>} config Store configuration.
     */
    function ComponentRxService(state, store) {
        this.state = state;
        this.store = store;
    }
    /**
     * Get provider for component Rx service.
     *
     * @param {ActionReducerMap<any, any> | InjectionToken<ActionReducerMap<any, any>>} reducers
     * @param {StoreConfig<any, any>} config
     */
    ComponentRxService.forComponent = function (reducers, config) {
        if (config === void 0) { config = {}; }
        return [
            ComponentRxService,
            { provide: _INITIAL_STATE, useValue: config.initialState },
            {
                provide: INITIAL_STATE,
                useFactory: _initialStateFactory,
                deps: [_INITIAL_STATE],
            },
            reducers instanceof InjectionToken
                ? { provide: INITIAL_REDUCERS, useExisting: reducers }
                : { provide: INITIAL_REDUCERS, useValue: reducers },
            {
                provide: META_REDUCERS,
                useValue: config.metaReducers ? config.metaReducers : [],
            },
            {
                provide: _REDUCER_FACTORY,
                useValue: config.reducerFactory
                    ? config.reducerFactory
                    : combineReducers,
            },
            {
                provide: REDUCER_FACTORY,
                deps: [_REDUCER_FACTORY, META_REDUCERS],
                useFactory: createReducerFactory,
            },
            ACTIONS_SUBJECT_PROVIDERS,
            REDUCER_MANAGER_PROVIDERS,
            SCANNED_ACTIONS_SUBJECT_PROVIDERS,
            STATE_PROVIDERS,
            STORE_PROVIDERS,
        ];
    };
    /**
     * Get state observable.
     *
     * @return {State<T>} State observable.
     */
    ComponentRxService.prototype.getStateObservable = function () {
        return this.state;
    };
    ComponentRxService.prototype.select = function (pathOrMapFn) {
        return this.store.select(pathOrMapFn);
    };
    ComponentRxService.prototype.lift = function (operator) { return this.store.lift(operator); };
    ComponentRxService.prototype.dispatch = function (action) { this.store.dispatch(action); };
    ComponentRxService.prototype.next = function (action) { return this.store.next(action); };
    ComponentRxService.prototype.error = function (err) { this.store.error(err); };
    ComponentRxService.prototype.complete = function () { this.store.complete(); };
    /* tslint:disable no-shadowed-variable */
    ComponentRxService.prototype.addReducer = function (key, reducer) {
        this.store.addReducer(key, reducer);
    };
    /* tslint:enable no-shadowed-variable */
    ComponentRxService.prototype.removeReducer = function (key) { this.store.removeReducer(key); };
    ComponentRxService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    ComponentRxService.ctorParameters = function () { return [
        { type: State, },
        { type: Store, },
    ]; };
    return ComponentRxService;
}());
export { ComponentRxService };
//# sourceMappingURL=component-rx.service.js.map